
From: Adrian Bunk <bunk@stusta.de>

This patch makes two needlessly global functions static.

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Acked-by: Sridhar Samudrala <sri@us.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 include/net/sctp/sm.h   |    3 ---
 net/sctp/sm_statefuns.c |   13 +++++++++++--
 2 files changed, 11 insertions(+), 5 deletions(-)

diff -puN include/net/sctp/sm.h~net-sctp-make-two-functions-static include/net/sctp/sm.h
--- 25/include/net/sctp/sm.h~net-sctp-make-two-functions-static	2005-05-31 02:11:49.000000000 -0700
+++ 25-akpm/include/net/sctp/sm.h	2005-05-31 02:11:49.000000000 -0700
@@ -130,7 +130,6 @@ sctp_state_fn_t sctp_sf_do_ecne;
 sctp_state_fn_t sctp_sf_ootb;
 sctp_state_fn_t sctp_sf_pdiscard;
 sctp_state_fn_t sctp_sf_violation;
-sctp_state_fn_t sctp_sf_violation_chunklen;
 sctp_state_fn_t sctp_sf_discard_chunk;
 sctp_state_fn_t sctp_sf_do_5_2_1_siminit;
 sctp_state_fn_t sctp_sf_do_5_2_2_dupinit;
@@ -258,8 +257,6 @@ struct sctp_chunk *sctp_make_fwdtsn(cons
 void sctp_chunk_assign_tsn(struct sctp_chunk *);
 void sctp_chunk_assign_ssn(struct sctp_chunk *);
 
-void sctp_stop_t1_and_abort(sctp_cmd_seq_t *commands, __u16 error);
-
 /* Prototypes for statetable processing. */
 
 int sctp_do_sm(sctp_event_t event_type, sctp_subtype_t subtype,
diff -puN net/sctp/sm_statefuns.c~net-sctp-make-two-functions-static net/sctp/sm_statefuns.c
--- 25/net/sctp/sm_statefuns.c~net-sctp-make-two-functions-static	2005-05-31 02:11:49.000000000 -0700
+++ 25-akpm/net/sctp/sm_statefuns.c	2005-05-31 02:11:49.000000000 -0700
@@ -92,6 +92,14 @@ static sctp_disposition_t sctp_sf_shut_8
 					     sctp_cmd_seq_t *commands);
 static struct sctp_sackhdr *sctp_sm_pull_sack(struct sctp_chunk *chunk);
 
+static void sctp_stop_t1_and_abort(sctp_cmd_seq_t *commands, __u16 error);
+
+static sctp_disposition_t sctp_sf_violation_chunklen(
+				     const struct sctp_endpoint *ep,
+				     const struct sctp_association *asoc,
+				     const sctp_subtype_t type,
+				     void *arg,
+				     sctp_cmd_seq_t *commands);
 
 /* Small helper function that checks if the chunk length
  * is of the appropriate length.  The 'required_length' argument
@@ -2318,7 +2326,7 @@ sctp_disposition_t sctp_sf_cookie_echoed
  *
  * This is common code called by several sctp_sf_*_abort() functions above.
  */
-void sctp_stop_t1_and_abort(sctp_cmd_seq_t *commands, __u16 error)
+static void sctp_stop_t1_and_abort(sctp_cmd_seq_t *commands, __u16 error)
 {
 	sctp_add_cmd_sf(commands, SCTP_CMD_NEW_STATE,
 			SCTP_STATE(SCTP_STATE_CLOSED));
@@ -3672,7 +3680,8 @@ sctp_disposition_t sctp_sf_violation(con
  *
  * Generate an  ABORT chunk and terminate the association.
  */
-sctp_disposition_t sctp_sf_violation_chunklen(const struct sctp_endpoint *ep,
+static sctp_disposition_t sctp_sf_violation_chunklen(
+				     const struct sctp_endpoint *ep,
 				     const struct sctp_association *asoc,
 				     const sctp_subtype_t type,
 				     void *arg,
_
